==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/sq.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Ndarje e federuar",
    "Invalid Federated Cloud ID" : "ID Federated Cloud e pavlefshme",
    "Sharing %s failed, because this item is already shared with %s" : "Ndarja për %s dështoi, ngaqë ky objekt është ndarë një herë me %s",
    "Not allowed to create a federated share with the same user" : "S’i lejohet të krijojë një ndarje të federuar me të njëjtin përdorues",
    "File is already shared with %s" : "Kartelë e ndarë tashmë me %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Ndarja për %s dështoi, s’u gjet dot %s, ndoshta shërbyesi është hëpërhë jashtë pune.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "\"/%3$s\" e morët si një ndarje të largët prej %1$s (në emër të %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "\"/%3$s\" e morët si një ndarje të largët prej %1$s",
    "Accept" : "Pranoje",
    "Decline" : "Hidhe poshtë",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Ndani me mua përmes ID-së time për #ownCloud Federated Cloud, shihni %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Ndani me mua përmes ID-së time për #ownCloud Federated Cloud",
    "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
    "Open documentation" : "Hap dokumentimin",
    "Allow users on this server to send shares to other servers" : "Lejoju përdoruesve në këtë shërbyes të dërgojnë ndarje në shërbyes të tjerë",
    "Allow users on this server to receive shares from other servers" : "Lejoju përdoruesve në këtë shërbyes të marrin ndarje nga shërbyes të tjerë",
    "Federated Cloud" : "Re e Federuar",
    "Your Federated Cloud ID:" : "ID-ja juaj për Re të Federuar:",
    "Share it:" : "Ndajeni:",
    "Add to your website" : "Shtojeni te sajti juaj",
    "Share with me via ownCloud" : "Ndani me mua përmes ownCloud-it",
    "HTML Code:" : "Kod HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/sq.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Ndarje e federuar",
    "Invalid Federated Cloud ID" : "ID Federated Cloud e pavlefshme",
    "Sharing %s failed, because this item is already shared with %s" : "Ndarja për %s dështoi, ngaqë ky objekt është ndarë një herë me %s",
    "Not allowed to create a federated share with the same user" : "S’i lejohet të krijojë një ndarje të federuar me të njëjtin përdorues",
    "File is already shared with %s" : "Kartelë e ndarë tashmë me %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Ndarja për %s dështoi, s’u gjet dot %s, ndoshta shërbyesi është hëpërhë jashtë pune.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "\"/%3$s\" e morët si një ndarje të largët prej %1$s (në emër të %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "\"/%3$s\" e morët si një ndarje të largët prej %1$s",
    "Accept" : "Pranoje",
    "Decline" : "Hidhe poshtë",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Ndani me mua përmes ID-së time për #ownCloud Federated Cloud, shihni %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Ndani me mua përmes ID-së time për #ownCloud Federated Cloud",
    "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
    "Open documentation" : "Hap dokumentimin",
    "Allow users on this server to send shares to other servers" : "Lejoju përdoruesve në këtë shërbyes të dërgojnë ndarje në shërbyes të tjerë",
    "Allow users on this server to receive shares from other servers" : "Lejoju përdoruesve në këtë shërbyes të marrin ndarje nga shërbyes të tjerë",
    "Federated Cloud" : "Re e Federuar",
    "Your Federated Cloud ID:" : "ID-ja juaj për Re të Federuar:",
    "Share it:" : "Ndajeni:",
    "Add to your website" : "Shtojeni te sajti juaj",
    "Share with me via ownCloud" : "Ndani me mua përmes ownCloud-it",
    "HTML Code:" : "Kod HTML:",
    "Add to your ownCloud" : "Shtojeni te ownCloud-i juaj"
},
"nplurals=2; plural=(n != 1);");
